# 0.1.6 8/13/2022
- Fixed AddOn.GetAddons 
- Set following as defaults in GetAddons: property=[name] limit={start=0,max=99}
- Handle objects in parameters (treat as dictionary)

# 0.1.3 6/29/2022
- Fix distribution
- Add kodi_help_tester.py - used to check the help output

# 0.1.2 6/19/2022
- repackage code, split KodiObj into own module
- clean up distribution 
- README updates
